@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.22 1999/11/16 17:30:05 bazsi Exp $
+ * $Id: affile.c,v 1.23 1999/11/20 19:13:39 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -56,7 +56,7 @@ static int do_open_file(struct ol_string *name, int flags, int mode, int *fd)
 */
 
 
-static int do_init_affile_source(struct log_handler *c, struct syslog_conf *cfg)
+static int do_init_affile_source(struct log_handler *c, struct syslog_config *cfg, struct persistent_config *persistent)
 {
 	CAST(affile_source, self, c);
 	int fd;
@@ -141,7 +141,7 @@ make_affile_dest_reaper(struct affile_dest_writer *affile_dest)
 */
 
 static int
-do_init_dest_writer(struct log_handler *c, struct syslog_conf *cfg)
+do_init_dest_writer(struct log_handler *c, struct syslog_config *cfg, struct persistent_config *persistent)
 {
 	CAST(affile_dest_writer, self, c);
 	int fd;
@@ -210,7 +210,7 @@ struct affile_dest_writer *make_affile_dest_writer(struct affile_dest *owner, st
 	 (sync_freq simple UINT32)
 	 (template_fname string)
 	 (writers object affile_dest_writer)
-	 (cfg object syslog_conf)))
+	 (cfg object syslog_config)))
 */
 
 void affile_set_syncfreq(struct log_dest_driver *c, int syncfreq)
@@ -317,7 +317,7 @@ void expand_macro(int id, char **fmt, char **args[], struct log_info *msg)
 			ADD_MACRO_ARG(c_format("%02i", tm->tm_mon + 1));
 			break;
 		case 'd':
-			ADD_MACRO_ARG(c_format("%02i", tm->tm_mday + 1));
+			ADD_MACRO_ARG(c_format("%02i", tm->tm_mday));
 			break;
 		}
 		break;
@@ -411,7 +411,7 @@ static struct affile_dest_writer *affile_find_writer(
 
 		/* allocate new writer */
 		p = make_affile_dest_writer(self, expanded_fname);
-		res = LOG_HANDLER_INIT(p, self->cfg);
+		res = LOG_HANDLER_INIT(p, self->cfg, NULL);
 		if (res & ST_QUIT)
 			return NULL;
 		p->next = self->writers;
@@ -421,7 +421,7 @@ static struct affile_dest_writer *affile_find_writer(
 	}
 }
 
-static int do_init_affile_dest(struct log_handler *c, struct syslog_conf *cfg)
+static int do_init_affile_dest(struct log_handler *c, struct syslog_config *cfg, struct persistent_config *persistent)
 {
 	CAST(affile_dest, self, c);
 	
