@@ -59,16 +59,17 @@ void inet_address_setport(struct address_info **a, UINT32 port)
 /* af_inet source connection */
 static int 
 do_init_afinet_source_connection(struct log_handler *c, 
-				 struct syslog_conf *cfg)
+				 struct syslog_config *cfg,
+				 struct persistent_config *persistent)
 {
 	CAST(afsocket_source_connection, self, c);
-	struct close_callback *cb;
-	struct resource_node *res;
+	CAST(inet_address_info, inet, self->client_addr);
 
-	res = REMEMBER_RESOURCE(cfg->resources, &self->client->super.super);
-	cb = make_afsocket_source_close_callback(res, cfg);
-
-	io_read(self->client, make_log_reader(1, c), cb);
+	notice("AF_INET client connected from %S, port %i\n", 
+	       inet->ip, inet->port);
+	io_read(self->client, 
+		make_log_reader(1, c), 
+		make_afsocket_source_close_callback(self));
 	
 	return ST_OK | ST_GOON;
 }
@@ -77,21 +78,35 @@ static void
 do_handle_afinet_line(struct log_handler *c, struct log_info *msg)
 {
 	CAST(afsocket_source_connection, self, c);
-	/* FIXME: somewhat ugly BSD workaround */
-	if (!msg->saddr) {
-		char sockaddr_buf[256];
-		struct sockaddr *sa = (struct sockaddr *) &sockaddr_buf;
-		int salen = sizeof(sockaddr_buf);
 
-		if (getpeername(self->client->super.fd, sa, &salen) != -1) {
-			msg->saddr = ol_space_alloc(salen);
-			memcpy(msg->saddr, sa, salen);
-		}
+	if (!msg->saddr) {
+		msg->saddr = self->client_addr;
 	}
 	HANDLE_LOG(self->super.next, msg);
 }
 
-struct log_handler *
+static int
+do_close_afinet_connection(struct afsocket_source_connection *c,
+                           int close_reason)
+{
+	CAST(inet_address_info, inet, c->client_addr);
+	notice("AF_INET client dropped connection from %S, port %i\n", 
+	       inet->ip, inet->port);
+	object_queue_remove(c->queue_node);
+	return ST_OK | ST_GOON;
+}
+
+static void
+do_destroy_afinet_connection(struct log_handler *c,
+			     struct syslog_config *cfg,
+			     struct persistent_config *persistent)
+{
+	CAST(afsocket_source_connection, self, c);
+
+	close_fd(&self->client->super, 0);
+}
+
+struct afsocket_source_connection *
 make_afinet_source_connection(struct io_fd *client,
 			      struct address_info *client_addr, 
 			      struct log_handler *next)
@@ -100,10 +115,12 @@ make_afinet_source_connection(struct io_fd *client,
 
 	self->super.super.init = do_init_afinet_source_connection;
 	self->super.super.handler = do_handle_afinet_line;
+	self->super.super.destroy = do_destroy_afinet_connection;
 	self->super.next = next;
 	self->client = client;
 	self->client_addr = client_addr;
-	return &self->super.super;
+	self->close = do_close_afinet_connection;
+	return self;
 }
 
 /* afinet_source */
@@ -112,7 +129,7 @@ make_afinet_source_connection(struct io_fd *client,
      (name afinet_source)
      (super afsocket_source)
      (vars
-       (cfg object syslog_conf)))
+       (cfg object syslog_config)))
 */
 
 void afinet_src_set_localip(struct log_source_driver *c, const char *ip)
@@ -156,21 +173,52 @@ do_open_afinet_connection(struct afsocket_source *c,
 			  struct address_info *client_addr)
 {
 	CAST(afinet_source, self, c);
-	struct log_handler *conn;
+	struct afsocket_source_connection *conn;
+	UINT32 res;
 
 	conn = make_afinet_source_connection(client, client_addr, self->super.super.super.next);
-	
-	return LOG_HANDLER_INIT(conn, self->cfg);
+	res = LOG_HANDLER_INIT(conn, self->cfg, NULL);
+	if ((res & ST_FAIL) == 0) {
+		conn->queue_node = 
+			object_queue_add_tail(self->super.connections, &conn->super.super.super);
+	}
+	return res;
+
 }
 
 static int 
-do_init_afinet_source(struct log_handler *c, struct syslog_conf *cfg)
+do_init_afinet_source(struct log_handler *c, 
+		      struct syslog_config *cfg,
+		      struct persistent_config *persistent)
 {
 	CAST(afinet_source, self, c);
 	struct listen_fd *listen;
 	int fd;
 
 	self->cfg = cfg;
+
+	if (persistent && (self->super.flags & AFSOCKET_KEEP_ALIVE)) {
+		CAST(inet_address_info, inet_addr, self->super.bind_addr);
+		struct ol_string *persistent_name;
+		struct persistent_info *p_info;
+
+		persistent_name = c_format("afinet_%S_%i", inet_addr->ip, inet_addr->port);
+		p_info = find_persistent_info(persistent, persistent_name->length, persistent_name->data);
+		ol_string_free(persistent_name);
+
+		if (p_info) {
+			CAST(object_queue, p, p_info->o);
+
+			FOR_OBJECT_QUEUE(p, n) {
+				CAST_SUBTYPE(log_handler, h, n);
+				append_log_handler(h, self->super.super.super.next);
+			}
+			self->super.connections = p;
+			p_info->kill = NULL;
+
+		}
+	}
+
 	fd = io_open_socket(self->super.bind_addr->family, 
 			    (self->super.flags & AFSOCKET_DGRAM)
 			    ? SOCK_DGRAM : SOCK_STREAM,
@@ -195,11 +243,11 @@ do_init_afinet_source(struct log_handler *c, struct syslog_conf *cfg)
 	}
 			
 	case AFSOCKET_DGRAM: {
-		struct log_handler *conn;
+		struct afsocket_source_connection *conn;
 		struct io_fd *client = make_io_fd(cfg->backend, fd);
 					
 		conn = make_afinet_source_connection(client, NULL, self->super.super.super.next);
-		LOG_HANDLER_INIT(conn, cfg);
+		LOG_HANDLER_INIT(conn, cfg, NULL);
 
 		break;
 	}
@@ -209,14 +257,43 @@ do_init_afinet_source(struct log_handler *c, struct syslog_conf *cfg)
 	return ST_OK | ST_GOON;		
 }
 
+static void
+do_destroy_afinet_source(struct log_handler *c,
+			 struct syslog_config *cfg,
+			 struct persistent_config *persistent)
+{
+	CAST(afinet_source, self, c);
+
+	if ((self->super.flags & AFSOCKET_KEEP_ALIVE) && persistent) {
+		CAST(inet_address_info, inet_addr, self->super.bind_addr);
+		struct persistent_info *p;
+
+		p = make_persistent_info
+			(c_format("afinet_%S_%i", 
+				  inet_addr->ip, inet_addr->port),
+			 &self->super.connections->super, 
+			 NULL);
+		add_persistent_info(persistent, p);
+	}
+	else {
+		FOR_OBJECT_QUEUE(self->super.connections, n) {
+			CAST_SUBTYPE(log_handler, p, n);
+
+			LOG_HANDLER_DESTROY(p, cfg, NULL);
+		}
+	}
+}
+
 struct log_source_driver *make_afinet_source(struct address_info *bind_addr, UINT32 flags)
 {
         NEW(afinet_source, self);
 
-        self->super.super.super.super.init = do_init_afinet_source;
+        self->super.super.super.super.init = do_init_afinet_source;        
+        self->super.super.super.super.destroy = do_destroy_afinet_source;
 	self->super.open_connection = do_open_afinet_connection;
 	self->super.bind_addr = bind_addr;
         self->super.flags = flags;
+	self->super.connections = make_object_queue();
         return &self->super.super;
 }
 
@@ -227,7 +304,7 @@ struct log_source_driver *make_afinet_source(struct address_info *bind_addr, UIN
      (vars
        (dest object io_fd)
        (dest_buf object abstract_buffer)
-       (cfg object syslog_conf)))
+       (cfg object syslog_config)))
 */
 
 /* af_inet destination */
@@ -270,7 +347,9 @@ void afinet_dest_set_destport(struct log_dest_driver *c, UINT32 port)
 	inet_address_setport(&dest->dest_addr, port);
 }
 
-static int do_init_afinet_dest(struct log_handler *c, struct syslog_conf *cfg)
+static int do_init_afinet_dest(struct log_handler *c, 
+			       struct syslog_config *cfg,
+			       struct persistent_config *persistent)
 {
 	CAST(afinet_dest, self, c);
 	int fd;
