@@ -31,7 +31,7 @@
 #include "cfgfile.h"
 #include "log.h"
 
-static struct syslog_conf *assigned_configuration = NULL;
+static struct syslog_config *assigned_configuration = NULL;
 
 static int write_internal_message(int level, UINT32 length, UINT8 *data)
 {
@@ -63,7 +63,9 @@ void set_error_internal(void)
 	error_write = write_internal_message;
 }
 
-static int do_init_afinter(struct log_handler *c, struct syslog_conf *cfg)
+static int do_init_afinter(struct log_handler *c, 
+			   struct syslog_config *cfg,
+			   struct persistent_config *persistent)
 {
 	CAST(log_source_driver, self, c);
 	if (assigned_configuration == NULL) {
@@ -77,11 +79,13 @@ static int do_init_afinter(struct log_handler *c, struct syslog_conf *cfg)
 	}
 }
 
-static int do_destroy_afinter(struct log_handler *c, struct syslog_conf *cfg)
+static void 
+do_destroy_afinter(struct log_handler *c, 
+		   struct syslog_config *cfg, 
+		   struct persistent_config *persistent)
 {
 	if (cfg == assigned_configuration)
 		assigned_configuration = NULL;
-	return 0;
 }
 
 struct log_source_driver *make_afinter_source(void)
