@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afsocket.c,v 1.16 1999/10/20 19:30:01 bazsi Exp $
+ * $Id: afsocket.c,v 1.17 1999/11/20 19:13:39 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -51,26 +51,22 @@
        (name afsocket_source_close_callback)
        (super close_callback)
        (vars
-          (res simple "struct resource_node *")
-	  (cfg object syslog_conf)))
+         (connection object afsocket_source_connection)))
 */
 
 static int do_afsocket_src_close(struct close_callback *c, int close_reason)
 {
 	CAST(afsocket_source_close_callback, self, c);
-	
-	KILL_RESOURCE_NODE(self->cfg->resources, self->res);
-	return 0;
+
+	return CLOSE_CONNECTION(self->connection, close_reason);
 }
 
 struct close_callback *
-make_afsocket_source_close_callback(struct resource_node *res, 
-				    struct syslog_conf *cfg)
+make_afsocket_source_close_callback(struct afsocket_source_connection *connection)
 {
 	NEW(afsocket_source_close_callback, self);
 	self->super.f = do_afsocket_src_close;
-	self->cfg = cfg;
-	self->res = res;
+	self->connection = connection;
 	return &self->super;
 }
 
@@ -107,6 +103,16 @@ make_afsocket_accept_callback(struct io_backend *backend,
 	return &self->super;
 }
 
+/* afsocket_source */
+void afsocket_set_keep_alive(struct log_source_driver *c, int enable)
+{
+	CAST_SUBTYPE(afsocket_source, self, c);
+
+	if (enable)
+		self->flags |= AFSOCKET_KEEP_ALIVE;
+	else
+		self->flags &= ~AFSOCKET_KEEP_ALIVE;
+}
 
 /* CLASS:
      (class
