@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afsocket.h,v 1.9 1999/10/20 19:30:01 bazsi Exp $
+ * $Id: afsocket.h,v 1.10 1999/11/20 19:13:39 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -37,6 +37,9 @@
 #include "afsocket.h.x"
 #undef CLASS_DECLARE
 
+#define AFSOCKET_DGRAM       0x0001
+#define AFSOCKET_STREAM      0x0002
+#define AFSOCKET_KEEP_ALIVE  0x0100
 
 #define AFINET_YES            3
 #define AFINET_NO             0
@@ -54,25 +57,27 @@
 #define AFINET_ENCRYPT_MASK   0x00C0
 #define AFINET_ENCRYPT_SHIFT  6
 
+
 /* CLASS:
      (class
        (name afsocket_source_connection)
        (super log_handler_pipe)
        (vars
+	 (queue_node simple "struct object_queue_node *")
          (client object io_fd)
-         (client_addr object address_info)))
+         (client_addr object address_info)
+	 (close method int "int close_reason")))
 */
 
+#define CLOSE_CONNECTION(c, r) ((c)->close(c, r))
+
 struct close_callback *
-make_afsocket_source_close_callback(struct resource_node *res, 
-				    struct syslog_conf *cfg);
+make_afsocket_source_close_callback(struct afsocket_source_connection *);
 
 struct fd_listen_callback *
 make_afsocket_accept_callback(struct io_backend *backend, 
 			      struct afsocket_source *source);
 
-#define AFSOCKET_DGRAM       0x0001
-#define AFSOCKET_STREAM      0x0002
 
 /* CLASS:
      (class
@@ -81,6 +86,7 @@ make_afsocket_accept_callback(struct io_backend *backend,
        (vars
 	 (flags simple UINT32)
 	 (bind_addr object address_info)
+	 (connections object object_queue)
 	 (open_connection method int
 	                         "struct io_fd *" 
 				 "struct address_info *a")))
@@ -109,6 +115,8 @@ make_afsocket_dest_connected(struct io_backend *backend,
 			     struct afsocket_dest *dest);
 
 
+void afsocket_set_keep_alive(struct log_source_driver *c, int enable);
+
 void afunix_set_owner(struct log_source_driver *c, const char *owner);
 void afunix_set_group(struct log_source_driver *c, const char *group);
 void afunix_set_perm(struct log_source_driver *c, int perm);
