@@ -195,7 +195,10 @@ void afstreams_set_sundoor(struct log_source_driver *c, const char *door)
 	self->door_name = c_format_cstring("%z", door);
 }
 
-static int do_init_afstreams_source(struct log_handler *c, struct syslog_conf *cfg)
+static int 
+do_init_afstreams_source(struct log_handler *c, 
+			 struct syslog_config *cfg, 
+			 struct persistent_config *persistent)
 {
 	CAST(afstreams_source, self, c);
 	int fd;
@@ -279,7 +282,10 @@ void afstreams_set_sundoor(struct log_source_driver *c, const char *door_name)
 {
 }
 
-static int do_init_afstreams_source(struct log_handler *c, struct syslog_conf *cfg)
+static int 
+do_init_afstreams_source(struct log_handler *c, 
+			 struct syslog_config *cfg,
+			 struct persistent_config *persistent)
 {
 	CAST(afstreams_source, self, c);
 	werror("sun-streams support not compiled in (STREAM=%S)\n", self->name);
