@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id$
+ * $Id: afunix.c,v 1.9 1999/11/20 19:13:39 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -27,6 +27,7 @@
 #include "cfgfile.h"
 #include "format.h"
 #include "pkt_buffer.h"
+#include "queue.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -41,16 +42,15 @@
 /* af_unix source connection */
 
 static int
-do_init_afunix_connection(struct log_handler *c, struct syslog_conf *cfg)
+do_init_afunix_connection(struct log_handler *c, 
+			  struct syslog_config *cfg,
+			  struct persistent_config *persistent)
 {
 	CAST(afsocket_source_connection, self, c);
-	struct close_callback *cb;
-	struct resource_node *res;
 
-	res = REMEMBER_RESOURCE(cfg->resources, &self->client->super.super);
-	cb = make_afsocket_source_close_callback(res, cfg);
-
-	io_read(self->client, make_log_reader(1, c), cb);
+	io_read(self->client, 
+		make_log_reader(1, c), 
+		make_afsocket_source_close_callback(self));
 	
 	return ST_OK | ST_GOON;
 }
@@ -68,7 +68,25 @@ static void do_handle_afunix_line(struct log_handler *c, struct log_info *msg)
 	HANDLE_LOG(self->super.next, msg);
 }
 
-struct log_handler *
+static int 
+do_close_afunix_connection(struct afsocket_source_connection *c,
+			   int close_reason)
+{
+	object_queue_remove(c->queue_node);
+	return ST_OK | ST_GOON;
+}
+
+static void
+do_destroy_afunix_connection(struct log_handler *c,
+			     struct syslog_config *cfg,
+			     struct persistent_config *persistent)
+{
+	CAST(afsocket_source_connection, self, c);
+
+	close_fd(&self->client->super, 0);
+}
+
+static struct afsocket_source_connection *
 make_afunix_source_connection(struct io_fd *client, 
 			      struct address_info *client_addr,
 			      struct log_handler *next)
@@ -77,10 +95,12 @@ make_afunix_source_connection(struct io_fd *client,
 
 	self->super.super.init = do_init_afunix_connection;
 	self->super.super.handler = do_handle_afunix_line;
+	self->super.super.destroy = do_destroy_afunix_connection;
 	self->super.next = next;
+	self->close = do_close_afunix_connection;
 	self->client = client;
 	self->client_addr = client_addr;
-	return &self->super.super;
+	return self;
 }
 
 /* CLASS:
@@ -91,7 +111,7 @@ make_afunix_source_connection(struct io_fd *client,
          (owner string)
 	 (group string)
 	 (perm simple int)
-	 (cfg object syslog_conf)))
+	 (cfg object syslog_config)))
 */
 
 void afunix_set_owner(struct log_source_driver *c, const char *owner)
@@ -125,26 +145,55 @@ do_open_unix_connection(struct afsocket_source *c,
 			struct address_info *client_addr)
 {
 	CAST(afunix_source, self, c);
-	struct log_handler *conn;
+	struct afsocket_source_connection *conn;
+	UINT32 res;
 
 	conn = make_afunix_source_connection(client, client_addr, self->super.super.super.next);
-	
-	return LOG_HANDLER_INIT(conn, self->cfg);
+	res = LOG_HANDLER_INIT(conn, self->cfg, NULL);
+	if ((res & ST_FAIL) == 0) {
+		conn->queue_node = 
+			object_queue_add_tail(self->super.connections, &conn->super.super.super);
+	}
+	return res;
 }
 
-int do_init_afunix_source(struct log_handler *c, struct syslog_conf *cfg)
+int do_init_afunix_source(struct log_handler *c, 
+			  struct syslog_config *cfg,
+			  struct persistent_config *persistent)
 {
 	CAST(afunix_source, self, c);
-	CAST(unix_address_info, bind_addr, self->super.bind_addr);
+	CAST(unix_address_info, unix_addr, self->super.bind_addr);
 	struct group *grp = NULL;
 	struct passwd *pwd = NULL;
 	int fd;
 
+	if (persistent && (self->super.flags & AFSOCKET_KEEP_ALIVE) &&
+	    (self->super.flags & AFSOCKET_STREAM)) {
+		struct ol_string *persistent_name;
+		struct persistent_info *p_info;
+
+		persistent_name = c_format("afunix_%S", unix_addr->path);
+		p_info = find_persistent_info(persistent, persistent_name->length, persistent_name->data);
+		ol_string_free(persistent_name);
+
+		if (p_info) {
+			CAST(object_queue, p, p_info->o);
+
+			FOR_OBJECT_QUEUE(p, n) {
+				CAST_SUBTYPE(log_handler, h, n);
+				append_log_handler(h, self->super.super.super.next);
+			}
+			self->super.connections = p;
+			p_info->kill = NULL;
+
+		}
+	}
+
 	self->cfg = cfg;
-	fd = io_open_socket(bind_addr->super.family, 
+	fd = io_open_socket(unix_addr->super.family, 
 			    self->super.flags & AFSOCKET_DGRAM ? SOCK_DGRAM : SOCK_STREAM,
 			    0, 
-			    &bind_addr->super);
+			    &unix_addr->super);
 	if (fd < 0) {
 		return ST_QUIT | ST_FAIL;
 	}
@@ -153,8 +202,8 @@ int do_init_afunix_source(struct log_handler *c, struct syslog_conf *cfg)
 		pwd = getpwnam(self->owner->data);
 	if (self->group)
 		grp = getgrnam(self->group->data);
-	chown(bind_addr->path->data, pwd ? pwd->pw_uid : -1, grp ? grp->gr_gid : -1);
-	chmod(bind_addr->path->data, self->perm);
+	chown(unix_addr->path->data, pwd ? pwd->pw_uid : -1, grp ? grp->gr_gid : -1);
+	chmod(unix_addr->path->data, self->perm);
 
 	switch (self->super.flags & 0x0003) {
 	case AFSOCKET_STREAM: {
@@ -173,11 +222,11 @@ int do_init_afunix_source(struct log_handler *c, struct syslog_conf *cfg)
 	}
 			
 	case AFSOCKET_DGRAM: {
-		struct log_handler *conn;
+		struct afsocket_source_connection *conn;
 		struct io_fd *client = make_io_fd(cfg->backend, fd);
 					
-		conn = make_afunix_source_connection(client, NULL, c);
-		LOG_HANDLER_INIT(conn, cfg);
+		conn = make_afunix_source_connection(client, NULL, self->super.super.super.next);
+		LOG_HANDLER_INIT(conn, cfg, NULL);
 
 		break;
 	}
@@ -188,16 +237,44 @@ int do_init_afunix_source(struct log_handler *c, struct syslog_conf *cfg)
 	return ST_OK | ST_GOON;		
 }
 
+static void
+do_destroy_afunix_source(struct log_handler *c,
+			 struct syslog_config *cfg,
+			 struct persistent_config *persistent)
+{
+	CAST(afunix_source, self, c);
+
+	if ((self->super.flags & AFSOCKET_KEEP_ALIVE) && persistent) {
+		CAST(unix_address_info, unix_addr, self->super.bind_addr);
+		struct persistent_info *p;
+
+		p = make_persistent_info
+			(c_format("afunix_%S", unix_addr->path),
+			 &self->super.connections->super, 
+			 NULL);
+		add_persistent_info(persistent, p);
+	}
+	else {
+		FOR_OBJECT_QUEUE(self->super.connections, n) {
+			CAST_SUBTYPE(log_handler, p, n);
+
+			LOG_HANDLER_DESTROY(p, cfg, NULL);
+		}
+	}
+}
+
 struct log_source_driver *
 make_afunix_source(struct address_info *bind_addr, UINT32 flags)
 {
         NEW(afunix_source, self);
 
         self->super.super.super.super.init = do_init_afunix_source;
+	self->super.super.super.super.destroy = do_destroy_afunix_source;
 	self->super.bind_addr = bind_addr;
         self->super.flags = flags;
 	self->super.open_connection = do_open_unix_connection;
 	self->perm = 0666;
+	self->super.connections = make_object_queue();
 	
         return &self->super.super;
 }
@@ -210,7 +287,7 @@ make_afunix_source(struct address_info *bind_addr, UINT32 flags)
      (vars
        (dest object io_fd)
        (dest_buf object abstract_buffer)
-       (cfg object syslog_conf)))
+       (cfg object syslog_config)))
 */
 
 void do_handle_afunix_dest(struct log_handler *c, struct log_info *msg)
@@ -218,12 +295,14 @@ void do_handle_afunix_dest(struct log_handler *c, struct log_info *msg)
 	CAST(afunix_dest, self, c);
 
 	if (self->dest_buf) {
-		A_WRITE_STRING(&self->dest_buf->super, c_format("<%i>%S %S %S%c", msg->pri, msg->date, msg->host, msg->msg, 0));
+		A_WRITE_STRING(&self->dest_buf->super, c_format("<%i>%S %S%c", msg->pri, msg->date, msg->msg, 0));
 	}
 	log_info_free(msg);
 }
 
-static int do_init_afunix_dest(struct log_handler *c, struct syslog_conf *cfg)
+static int do_init_afunix_dest(struct log_handler *c, 
+			       struct syslog_config *cfg,
+			       struct persistent_config *persistent)
 {
 	CAST(afunix_dest, self, c);
 	struct connect_fd *conn_fd;
