@@ -45,7 +45,10 @@
        (username string)))
 */
 
-static int do_init_afuser_dest(struct log_handler *c, struct syslog_conf *cfg)
+static int 
+do_init_afuser_dest(struct log_handler *c, 
+		    struct syslog_config *cfg, 
+		    struct persistent_config *persistent)
 {
 	return ST_OK | ST_GOON;
 }
