@@ -19,20 +19,21 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: cfgfile.c,v 1.23 1999/11/16 17:30:05 bazsi Exp $
+ * $Id: cfgfile.c,v 1.24 1999/11/20 19:13:39 bazsi Exp $
  *
  ***************************************************************************/
 
 #include "cfgfile.h"
+
 #include <stdio.h>
 #include <string.h>
-
+#include <assert.h>
 
 #define CLASS_DEFINE
 #include "cfgfile.h.x"
 #undef CLASS_DEFINE
 
-struct syslog_conf *configuration;
+struct syslog_config *configuration;
 
 void add_dest_group(struct log_dest_group *grp)
 {
@@ -61,6 +62,63 @@ void add_log_connection(struct log_connection *conn)
 	configuration->connections = conn;
 }
 
+struct persistent_info *
+make_persistent_info(struct ol_string *name, 
+		     struct ol_object *o, 
+		     void (*kill)(struct ol_string *name, struct ol_object *obj))
+{
+	NEW(persistent_info, self);
+
+	self->name = name;
+	self->o = o;
+	self->kill = kill;
+	return self;
+}
+
+struct persistent_info *
+find_persistent_info(struct persistent_config *c, UINT32 length, const char *name)
+{
+	struct persistent_info *p;
+
+	for (p = c->nodes; p; p = p->next) {
+		if (p->name->length == length &&
+		    memcmp(p->name->data, name, length) == 0) {
+			return p;
+		}
+	}
+	return NULL;
+}
+
+void add_persistent_info(struct persistent_config *c, 
+			 struct persistent_info *node)
+{
+	struct persistent_info *p;
+
+	p = find_persistent_info(c, node->name->length, node->name->data);
+	assert(!p);
+
+	node->next = c->nodes;
+	c->nodes = node;
+}
+
+void kill_persistent_config(struct persistent_config *persistent)
+{
+	struct persistent_info *p;
+	for (p = persistent->nodes; p; p = p->next) {
+		if (p->kill)
+			(p->kill)(p->name, p->o);
+	}
+	persistent->nodes = NULL;
+}
+
+struct persistent_config *
+make_persistent_config(void)
+{
+	NEW(persistent_config, persistent);
+	return persistent;
+}
+
+/* cfgfile */
 #define RESOLVE_VAR(s, first, next, i) \
         for (s = first; s; s = s->next) { \
 	         if (i->name->length == s->name->length && \
@@ -75,7 +133,7 @@ void add_log_connection(struct log_connection *conn)
 	} \
 
 
-static int do_init_config(struct syslog_conf *self)
+static int do_init_config(struct syslog_config *self, struct persistent_config *p)
 {
 	struct log_source_group *s;
 	struct log_filter *f;
@@ -88,14 +146,14 @@ static int do_init_config(struct syslog_conf *self)
 	center = make_log_center(self->connections);
 	
 	for (s = self->sources; s; s = s->next_source_group) {
-		res = LOG_HANDLER_INIT(s, self);
+		res = LOG_HANDLER_INIT(s, self, p);
 		append_log_handler(s, center);
 		if (res & ST_FAIL)
 			return 0;
 	}
 	
 	for (d = self->destinations; d; d = d->next_dest_group) {
-		res = LOG_HANDLER_INIT(d, self);
+		res = LOG_HANDLER_INIT(d, self, p);
 		if (res & ST_FAIL)
 			return 0;
 	}
@@ -132,19 +190,19 @@ static int do_init_config(struct syslog_conf *self)
 	return 1;
 }
 
-static int do_destroy_config(struct syslog_conf *self)
+static int do_destroy_config(struct syslog_config *self, struct persistent_config *persistent)
 {
 	struct log_dest_group *d;
 	struct log_source_group *s;
 
 	for (s = self->sources; s; s = s->next_source_group) {
 		if (s->super.super.destroy)
-			(void) LOG_HANDLER_DESTROY(s, self);
+			LOG_HANDLER_DESTROY(s, self, persistent);
 	}
 	
 	for (d = self->destinations; d; d = d->next_dest_group) {
 		if (d->super.destroy)
-			(void) LOG_HANDLER_DESTROY(d, self);
+			LOG_HANDLER_DESTROY(d, self, persistent);
 	}
 	
 	KILL_RESOURCE_LIST(self->resources);
@@ -155,12 +213,12 @@ extern FILE *yyin;
 extern int yyparse();
 extern int yydebug;
 
-struct syslog_conf *make_syslog_conf(const char *name, struct io_backend *backend)
+struct syslog_config *make_syslog_config(const char *name, struct io_backend *backend)
 {
 	FILE *cfg;
 	int res;
 	
-	NEW(syslog_conf, self);
+	NEW(syslog_config, self);
 	
 	configuration = self;
 	self->init = do_init_config;
