@@ -37,10 +37,10 @@
 
 /* CLASS:
     (class
-      (name syslog_conf)
+      (name syslog_config)
       (vars
-        (init method int)
-	(destroy method int)
+        (init method int "struct persistent_config *")
+	(destroy method int "struct persistent_config *")
 	(resources object resource_list)
         (backend object io_backend)
 	; global options
@@ -58,16 +58,47 @@
         (connections object log_connection))) 
 */
 
-#define CONFIG_INIT(c) (c)->init(c)
-#define CONFIG_DESTROY(c) (c)->destroy(c)
+#define CONFIG_INIT(c, p) (c)->init(c, p)
+#define CONFIG_DESTROY(c, p) (c)->destroy(c, p)
 
-extern struct syslog_conf *configuration;
+/* CLASS:
+   (class 
+     (name persistent_info)
+     (vars
+       (name string)
+       (o object ol_object)
+       (kill pointer (function void "struct ol_string *name" "struct ol_object *o"))
+       (next object persistent_info)))
+*/
+
+struct persistent_info *
+make_persistent_info(struct ol_string *name, 
+		     struct ol_object *o, 
+		     void (*kill)(struct ol_string *name, struct ol_object *obj));
+
+/* info needed to kept persistent upon restart */
+/* CLASS:
+   (class
+     (name persistent_config)
+     (vars
+       (nodes object persistent_info)))
+*/
+
+struct persistent_info *find_persistent_info(struct persistent_config *p, UINT32 length, const char *name);
+
+void add_persistent_info(struct persistent_config *p, struct persistent_info *node);
+
+void kill_persistent_config(struct persistent_config *persistent);
+
+struct persistent_config *make_persistent_config(void);
+
+extern struct syslog_config *configuration;
 
 void add_dest_group(struct log_dest_group *grp);
 void add_source_group(struct log_source_group *grp);
 void add_log_connection(struct log_connection *conn);
 void add_filter_rule(struct log_filter *filter);
 
-struct syslog_conf *make_syslog_conf(const char *name, struct io_backend *backend);
+struct syslog_config *make_syslog_config(const char *name, struct io_backend *backend);
 
 #endif
