@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: destinations.c,v 1.14 1999/08/29 17:37:56 bazsi Exp $
+ * $Id: destinations.c,v 1.15 1999/11/20 19:13:39 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -62,7 +62,7 @@ static void add_host(struct log_info *msg)
 
 /* log_dest_group */
 
-static int do_init_group(struct log_handler *c, struct syslog_conf *cfg)
+static int do_init_group(struct log_handler *c, struct syslog_config *cfg, struct persistent_config *persistent)
 {
 	CAST(log_dest_group, self, c);
 	int res;
@@ -71,26 +71,26 @@ static int do_init_group(struct log_handler *c, struct syslog_conf *cfg)
 	
 	res = 0;
 	for (drv = self->drivers; drv; drv = drv->next_driver) {
-		res |= LOG_HANDLER_INIT(drv, cfg);
+		res |= LOG_HANDLER_INIT(drv, cfg, persistent);
 		if (res & ST_QUIT) 
 			break;
 	}
 	return res;
 }
 
-static int do_destroy_group(struct log_handler *c, struct syslog_conf *cfg)
+static void 
+do_destroy_group(struct log_handler *c, 
+		 struct syslog_config *cfg, 
+		 struct persistent_config *persistent)
 {
 	CAST(log_dest_group, self, c);
-	int res;
 	
 	struct log_dest_driver *drv;
 	
-	res = 0;
 	for (drv = self->drivers; drv; drv = drv->next_driver) {
 		if (drv->super.destroy)
-			res |= LOG_HANDLER_DESTROY(drv, cfg);
+			LOG_HANDLER_DESTROY(drv, cfg, persistent);
 	}
-	return res;
 }
 
 static void do_handle_log(struct log_handler *c, struct log_info *msg)
@@ -126,17 +126,17 @@ struct log_dest_group *make_dest_group(const char *name, struct log_dest_driver
        (super callback)
        (vars
          (handler object log_handler)
-	 (cfg object syslog_conf)))
+	 (cfg object syslog_config)))
 */
 
 static void do_reopen(struct callback *c)
 {
 	CAST(log_dest_reopen, self, c);
 
-	LOG_HANDLER_INIT(self->handler, self->cfg);
+	LOG_HANDLER_INIT(self->handler, self->cfg, NULL);
 }
 
-struct callback *make_dest_reopen(struct log_handler *handler, struct syslog_conf *cfg)
+struct callback *make_dest_reopen(struct log_handler *handler, struct syslog_config *cfg)
 {
 	NEW(log_dest_reopen, self);
 	self->super.f = do_reopen;
@@ -152,7 +152,7 @@ struct callback *make_dest_reopen(struct log_handler *handler, struct syslog_con
        (vars
          (handler object log_handler)
 	 (res simple "struct resource_node *")
-	 (cfg object syslog_conf)
+	 (cfg object syslog_config)
          (time_reopen simple int)))
 */
 
@@ -169,7 +169,7 @@ static int do_dest_close(struct close_callback *c, int reason)
 	return ST_OK | ST_GOON;
 }
 
-struct close_callback *make_dest_close(struct log_handler *handler, struct resource_node *res, int time_reopen, struct syslog_conf *cfg)
+struct close_callback *make_dest_close(struct log_handler *handler, struct resource_node *res, int time_reopen, struct syslog_config *cfg)
 {
 	NEW(dest_close, self);
 
