@@ -31,7 +31,8 @@
 
 #include <sys/time.h>
 
-struct syslog_conf;
+struct syslog_config;
+struct persistent_config;
 
 struct log_info {
 	UINT32 use_cnt;
@@ -40,7 +41,7 @@ struct log_info {
 	struct log_handler *source;
 	UINT32 pri;
 	UINT32 flags;
-	struct sockaddr *saddr;
+	struct address_info *saddr;
 	struct ol_string *msg;
 	struct ol_string *date;
 	struct ol_string *program;
@@ -61,13 +62,15 @@ struct log_info {
        (vars
          (params object log_handler_params)
          (handler method void "struct log_info *")
-         (init method int "struct syslog_conf *")
-	 (destroy method int "struct syslog_conf *")))
+         (init method int "struct syslog_config *" 
+	                  "struct persistent_config *")
+	 (destroy method void "struct syslog_config *" 
+	                      "struct persistent_config *")))
 */
 
 #define HANDLE_LOG(l, i) (((struct log_handler *) l)->handler((struct log_handler *) (l), i))
-#define LOG_HANDLER_INIT(l, c) ((struct log_handler *) l)->init((struct log_handler *) (l), c)
-#define LOG_HANDLER_DESTROY(l, c) ((struct log_handler *) l)->destroy((struct log_handler *) (l), c)
+#define LOG_HANDLER_INIT(l, c, p) ((struct log_handler *) l)->init((struct log_handler *) (l), c, p)
+#define LOG_HANDLER_DESTROY(l, c, p) ((struct log_handler *) l)->destroy((struct log_handler *) (l), c, p)
 
 /* CLASS:
      (class
