@@ -58,17 +58,20 @@ static void do_reread_config(struct callback *c)
 	switch (self->state) {
 	case 0:
 	case 2:
-		CONFIG_DESTROY(self->backend->configuration);
+		self->backend->persistent = make_persistent_config();
+		CONFIG_DESTROY(self->backend->configuration, self->backend->persistent);
 		self->state++;
 		self->backend->oldconfig = self->backend->configuration;
 		self->backend->configuration = self->backend->newconfig;
 		io_callout(&self->backend->super, 0, c);
 		break;
 	case 1:
-		if (CONFIG_INIT(self->backend->configuration)) {
+		if (CONFIG_INIT(self->backend->configuration, self->backend->persistent)) {
 			notice("new configuration initialized\n");
 			self->backend->newconfig = NULL;
 			self->backend->oldconfig = NULL;
+			kill_persistent_config(self->backend->persistent);
+			self->backend->persistent = NULL;
 		}
 		else {
 			/* initializing the new configuration was not 
@@ -81,13 +84,15 @@ static void do_reread_config(struct callback *c)
 		}
 		break;
 	case 3:
-		if (CONFIG_INIT(self->backend->configuration)) {
+		if (CONFIG_INIT(self->backend->configuration, self->backend->persistent)) {
 			notice("Initializing new configuration failed, reverting to old config.\n");
 		}
 		else {
 			/* this is a fatal error, but no stderr & no log output */
 			exit(137);
 		}
+		kill_persistent_config(self->backend->persistent);
+		self->backend->persistent = NULL;
 		break;
 	}
 }
@@ -97,9 +102,10 @@ static void do_reread_config(struct callback *c)
      (name syslog_backend)
      (super io_backend)
      (vars
-       (newconfig object syslog_conf)
-       (oldconfig object syslog_conf)
-       (configuration object syslog_conf)))
+       (newconfig object syslog_config)
+       (oldconfig object syslog_config)
+       (persistent object persistent_config)
+       (configuration object syslog_config)))
 */
 
 int sighuprecvd = 0;
@@ -132,7 +138,7 @@ int main_loop(struct syslog_backend *backend)
 		if (sighuprecvd) {
 
 			notice("SIGHUP received, restarting syslog-ng\n");
-			backend->newconfig = make_syslog_conf(cfgfilename, &backend->super);
+			backend->newconfig = make_syslog_config(cfgfilename, &backend->super);
 			if (backend->newconfig) {
 				static struct reread_config r = 
 				{ { STATIC_HEADER, do_reread_config }, NULL, 0 };
@@ -147,7 +153,7 @@ int main_loop(struct syslog_backend *backend)
 		}
 		if (sigtermrecvd) {
 			notice("syslog-ng version %z going down\n", VERSION);
-			CONFIG_DESTROY(backend->configuration);
+			CONFIG_DESTROY(backend->configuration, 0);
 			exit_main_loop = 1;
 		}
 	}
@@ -250,7 +256,7 @@ int main(int argc, char **argv)
 
 	init_backend(&backend->super);
 	
-	backend->configuration = make_syslog_conf(cfgfilename, &backend->super);
+	backend->configuration = make_syslog_config(cfgfilename, &backend->super);
 	if (!backend->configuration) {
 		werror("Parse error reading configuration file, exiting.\n");
 		return 1;
@@ -259,7 +265,7 @@ int main(int argc, char **argv)
 		do_fork = 0;
 	if (do_fork)
 		go_background();
-	if (!CONFIG_INIT(backend->configuration)) {
+	if (!CONFIG_INIT(backend->configuration, NULL)) {
 		werror("Error initializing configuration, exiting.\n");
 		if (do_fork) kill(getppid(), SIGTERM);
 		return 2;
