@@ -59,8 +59,7 @@ static int do_handle_line(struct log_reader *self, UINT32 length, UINT8 *data, a
 
 	logmsg = make_log_info(length, data);
 	if (addrlen) {
-		logmsg->saddr = ol_space_alloc(addrlen);
-		memcpy(logmsg->saddr, addr, addrlen);
+		logmsg->saddr = sockaddr2address_info(addrlen, addr);
 	}
 	HANDLE_LOG(self->next, logmsg);
 	return ST_OK | ST_GOON;
@@ -145,18 +144,20 @@ struct read_handler *make_log_reader(UINT32 userecv, struct log_handler *next)
 
 /* source_group */
 
-static struct ol_string *get_source_hostname(struct sockaddr *sa)
+static struct ol_string *get_source_hostname(struct address_info *a)
 {
 	struct ol_string *name;
 	static struct ol_string *hostname = NULL;
 	
-	if (sa && sa->sa_family == AF_INET) {
+	if (a && a->super.isa == &inet_address_info_class) {
+		CAST(inet_address_info, inet_addr, a);
 	        struct hostent *hp;
 		char *hname, *p;
 
-		hp = gethostbyaddr((char *) &((struct sockaddr_in *) sa)->sin_addr, sizeof(struct in_addr), AF_INET);
-		if (!hp)
-			hname = inet_ntoa(((struct sockaddr_in *) sa)->sin_addr);
+		hp = gethostbyaddr((char *) &(inet_addr->sa.sin_addr), sizeof(struct in_addr), AF_INET);
+		if (!hp) {
+			return ol_string_use(inet_addr->ip);
+		}
 		else {
 			hname = hp->h_name;
 			p = strchr(hname, '.');
@@ -208,7 +209,7 @@ static void do_add_source_name(struct log_handler *c, struct log_info *logmsg)
 	HANDLE_LOG(self->super.next, logmsg);
 }
 
-static int do_init_group(struct log_handler *c, struct syslog_conf *cfg)
+static int do_init_group(struct log_handler *c, struct syslog_config *cfg, struct persistent_config *persistent)
 {
 	CAST(log_source_group, self, c);
 	int res;
@@ -218,27 +219,24 @@ static int do_init_group(struct log_handler *c, struct syslog_conf *cfg)
 	self->long_hostnames = cfg->long_hostnames;
 	res = 0;
 	for (drv = self->drivers; drv; drv = drv->next_driver) {
-		res = LOG_HANDLER_INIT(drv, cfg);
+		res = LOG_HANDLER_INIT(drv, cfg, persistent);
 		if (res & ST_QUIT) 
 			break;
 	}
 	return res;
 }
 
-static int do_destroy_group(struct log_handler *c, struct syslog_conf *cfg)
+static void do_destroy_group(struct log_handler *c, struct syslog_config *cfg, struct persistent_config *persistent)
 {
 	CAST(log_source_group, self, c);
-	int res;
 	
 	struct log_source_driver *drv;
 	
 	self->long_hostnames = cfg->long_hostnames;
-	res = 0;
 	for (drv = self->drivers; drv; drv = drv->next_driver) {
 		if (drv->super.super.destroy)
-			res |= LOG_HANDLER_DESTROY(drv, cfg);
+			LOG_HANDLER_DESTROY(drv, cfg, persistent);
 	}
-	return res;
 }
 
 void set_source_drivers(struct log_source_group *src, struct log_source_driver *drvs)
