@@ -49,7 +49,7 @@
        (name log_source_group)
        (super log_handler_pipe)
        (vars
-         (next_source_group object log_source_group) ; for linking into syslog_conf
+         (next_source_group object log_source_group) ; for linking into syslog_config
          (used simple int)			 ; true, when referenced
 	 (long_hostnames simple int)
          (drivers object log_source_driver)
